// for standard types like uint8_t
#include <stdint.h>

#include "hardware.h"

// chip configuration
__CONFIG(
	CP_OFF &  // Code protection off
	LVP_OFF &  // Low-Voltage Programming disabled
	BOREN_OFF &  // Brown-out Detect disabled
	MCLRE_OFF &  // RA5/MCLR pin function is digital input, MCLR internally tied to VDD
	PWRTE_ON &  // PWRT enabled
	WDTE_OFF &  // Watchdog Timer disabled
	FOSC_EC  // I/O function on RA6/OSC2/CLKOUT pin, CLKIN on RA7/OSC1/CLKIN
);

uint8_t g_portA = 0;
uint8_t g_portD = 0;

void enableInterrupt()
{
	// global interrupt enable
	GIE = 1;
}

void hardwareInit()
{
	// init ports
	PORTC = 0xff;
	PORTE = 0;

	// 0=output, 1=input
	TRISA = 0b10000000;
	TRISB = 0b11111111;
	TRISC = 0b00000000;
	TRISD = 0b00001111;
	TRISE = 0b11111110;
	ANSEL = 0;
	ANSELH = 0;

	// interrupt on TMR2
	PIE1 = 2;

	// period register
	PR2 = 249;

	// peripheral interrupt must be enabled for overflow interrupts
	PEIE = 1;  

	// start timer 1, prescale 1, postscale 5
	T2CON = 0b00100100;

	// clear interrupt flag
	TMR2IF = 0;
}
